@@ -55,11 +55,15 @@ use RT::Shredder;
 
 package RT::Extension::MergeUsers;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 =head1 NAME
 
 RT::Extension::MergeUsers - Merges two users into the same effective user
+ 
+=head1 RT VERSION
+
+Works with RT 4.0, 4.2 and 4.4.
 
 =head1 DESCRIPTION
 
@@ -195,7 +199,7 @@ sub CanonicalizeEmailAddress {
     my $canonical_user = RT::User->new( $RT::SystemUser );
     $canonical_user->LoadByCols( EmailAddress => $address );
     return $address unless $canonical_user->id;
-    return $address unless $canonical_user->EmailAddress ne $address;
+    return $address unless $canonical_user->EmailAddress && $canonical_user->EmailAddress ne $address;
     return $canonical_user->CanonicalizeEmailAddress(
         $canonical_user->EmailAddress
     );
